@@ -111,6 +111,15 @@ def get_app_ids(command_args, yaml_config):
     return api_id, app_id
 
 def check_language(command_line_params, yaml_config):
+    scanners = ''
+    if 'scanner' in yaml_config and yaml_config['scanner'] is not None:
+        scanners = yaml_config['scanner']
+    if 'scanner' in command_line_params and command_line_params['scanner'] is not None:
+        scanners = command_line_params['scanner']
+
+    if scanners.find('sast') < 0:
+        return True
+
     yaml_language = []
     if 'language' in yaml_config and yaml_config['language'] is not None:
         languages = yaml_config['language'].split(',')
@@ -131,7 +140,7 @@ def check_language(command_line_params, yaml_config):
     return 'language' in yaml_config or 'language' in command_line_params
 
 def version():
-    return '0.1.71'
+    return '0.1.72'
 
 def main():
     Utils.assert_docker_alive()
